@@ -1,6 +1,6 @@
 package URI::Fast;
 
-our $XS_VERSION = our $VERSION = '0.50_02';
+our $XS_VERSION = our $VERSION = '0.51_01';
 $VERSION =~ tr/_//;
 
 use utf8;
@@ -18,7 +18,11 @@ XSLoader::load('URI::Fast', $XS_VERSION);
 use Exporter 'import';
 
 our @EXPORT_OK = qw(
-  uri iri uri_split html_url
+  uri_split 
+  uri
+  iri
+  abs_uri
+  html_url
   encode uri_encode url_encode
   decode uri_decode url_decode
 );
@@ -319,27 +323,6 @@ sub unescape_tree {
   _walk($ref, $sub);
 }
 
-sub html_url ($;$) {
-  my ($uri_string, $source_uri) = @_;
-
-  # Remove characters specified by the URL standard
-  $uri_string =~ s|[\t\r\n]||g; # strip tabs, line feeds, and carriage returns
-  $uri_string =~ tr|\\|/|;      # convert backslashes to forward slashes
-
-  # Then, parse the URI string into a URI::Fast object
-  my $uri = uri $uri_string;
-
-  # If the URL begins with //, the scheme is replaced with that of a reference
-  # URI, presumably that of the source document from which the URI was read.
-  if ($source_uri && $uri_string =~ m|^//|) {
-    if (my $scheme = URI::Fast::uri( $source_uri )->scheme) {
-      $uri->scheme($scheme);
-    }
-  }
-
-  return $uri;
-}
-
 =encoding UTF8
 
 =head1 NAME
@@ -391,6 +374,26 @@ Similar to L</uri>, but returns a C<URI::Fast::IRI> object. A C<URI::Fast::IRI>
 differs from a C<URI::Fast> in that UTF-8 characters are permitted and will not
 be percent-encoded when modified.
 
+=head2 abs_uri
+
+Builds a new C<URI::Fast> from a relative URI string and makes it L</absolute>
+in relation to C<$base>.
+
+  my $uri = abs_uri 'some/path', 'http://www.example.com/fnord';
+  $uri->to_string; # "http://www.example.com/fnord/some/path"
+
+=head2 html_url
+
+Parses a URI string, removing whitespace characters ignored in URLs found in
+HTML documents, replacing backslashes with forward slashes, and making the
+URL L</normalize>d.
+
+If a base URL is specified, the C<URI::Fast> object returned will be made
+L</absolute> relative to that base URL.
+
+  # Resulting URL is "https://www.slashdot.org/recent"
+  my $url = html_url '//www.slashdot.org\recent', "https://www.slashdot.org";
+
 =head2 uri_split
 
 Behaves (hopefully) identically to L<URI::Split>, but roughly twice as fast.
@@ -404,17 +407,17 @@ See L</ENCODING>.
 =head2 new
 
 If desired, both C<URI::Fast> and L<URI::Fast::IRI> may be instantiated using
-the default constructor, C<new>.
+the default OO-flavored constructor, C<new>.
 
   my $uri = URI::Fast->new('http://www.example.com');
 
 =head2 new_abs
 
-Builds a new C<URI::Fast> from a relative URI string and makes it L</absolute>
-in relation to C<$base>.
+OO equivalent to L</abs_uri>.
 
-  my $uri = URI::Fast->new_abs('some/path', 'http://www.example.com/fnord');
-  $uri->to_string; # "http://www.example.com/fnord/some/path"
+=head2 new_html_url
+
+OO equivalent to L</html_url>.
 
 =head1 ATTRIBUTES
 
@@ -801,20 +804,6 @@ is a non-reference value.
     bat => '',
   }
 
-=head1 EXTRAS
-
-=head2 html_url
-
-Parses a URI string, first removing whitespace characters ignored in URLs
-found in HTML documents, replacing backslashes with forward slashes, and
-optionally defaulting the scheme to that of the document source URL when
-the URL begins with C<//>.
-
-  my $url = html_url "https://www.slashdot.org";
-
-  # Inheriting the scheme from $url
-  my $recent = html_url "//www.slashdot.org/recent", $url;
-
 =head1 CAVEATS
 
 This module is designed to parse URIs according to RFC 3986. Browsers parse
